// database row base class                                       -*- C++ -*-
// $Id: row_base.cc,v 1.2 2004/01/07 14:29:39 roger Exp $
//
// Copyright (C) 2003  Roger Leigh <rleigh@debian.org>
//
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#include <pqxx-object/row_base.h>

using namespace pqxxobject;

row_base::row_base():
  m_state(STATE_UNINITIALISED),
  m_modified(false)
{
}

row_base::row_base(state status,
		   bool modified):
  m_state(status),
  m_modified(modified)
{
}

row_base::row_base(const row_base& rhs):
  SigC::Object(),
  m_state(rhs.m_state),
  m_modified(rhs.m_modified)
{
}

row_base::~row_base()
{
}

row_base&
row_base::operator = (const row_base& rhs)
{
  m_state = rhs.m_state;
  m_modified = rhs.m_modified;
}

row_base::state
row_base::get_state() const
{
  return m_state;
}

bool
row_base::is_modified() const
{
  return m_modified;
}

void
row_base::refresh()
{
  refresh_impl();
  m_signal_refreshed.emit();
}

void
row_base::insert()
{
  insert_impl();
  m_signal_inserted.emit();
}

void
row_base::update()
{
  update_impl();
  m_signal_updated.emit();
}

void
row_base::erase()
{
  erase_impl();
  m_signal_erased.emit();
}

SigC::Signal0<void>&
row_base::signal_changed()
{
  return m_signal_changed;
}

SigC::Signal0<void>&
row_base::signal_refreshed()
{
  return m_signal_refreshed;
}

SigC::Signal0<void>&
row_base::signal_inserted()
{
  return m_signal_inserted;
}

SigC::Signal0<void>&
row_base::signal_updated()
{
  return m_signal_updated;
}

SigC::Signal0<void>&
row_base::signal_erased()
{
  return m_signal_erased;
}

void
row_base::refresh_impl()
{
}

void
row_base::insert_impl()
{
}

void
row_base::update_impl()
{
}

void
row_base::erase_impl()
{
}
