// database row base class                                       -*- C++ -*-
// $Id: row_base.h,v 1.2 2004/01/07 14:29:39 roger Exp $
//
// Copyright (C) 2003  Roger Leigh <rleigh@debian.org>
//
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#ifndef PQXX_OBJECT_ROW_BASE_H
#define PQXX_OBJECT_ROW_BASE_H

#include <sigc++/object.h>
#include <sigc++/signal.h>

namespace pqxxobject
{
  /**
   * Database row base class.
   */
  class row_base : public SigC::Object
  {
  public:
    enum state
      {
	STATE_UNINITIALISED,
	STATE_INITIALISED,
	STATE_INCONSISTENT
      };

    row_base();

    row_base(state status,
	     bool modified=false);

    row_base(const row_base& rhs);

    virtual ~row_base();


    row_base& operator = (const row_base& rhs);

    state get_state() const;

    bool is_modified() const;

    void refresh();
    void insert();
    void update();
    void erase();

    SigC::Signal0<void>& signal_changed();
    SigC::Signal0<void>& signal_refreshed();
    SigC::Signal0<void>& signal_inserted();
    SigC::Signal0<void>& signal_updated();
    SigC::Signal0<void>& signal_erased();

  protected:
    state m_state;
    bool m_modified;

    virtual void refresh_impl();
    virtual void insert_impl();
    virtual void update_impl();
    virtual void erase_impl();

    SigC::Signal0<void> m_signal_changed;
    SigC::Signal0<void> m_signal_refreshed;
    SigC::Signal0<void> m_signal_inserted;
    SigC::Signal0<void> m_signal_updated;
    SigC::Signal0<void> m_signal_erased;

  }; // class row_base

}; // namespace pqxxobject

#endif // PQXX_OBJECT_ROW_BASE_H
